---
last_modified_on: "2020-04-11"
component_title: "Add Tags"
description: "The Vector `add_tags` transform accepts and outputs `metric` events allowing you to add one or more metric tags."
event_types: ["metric"]
function_category: "shape"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+add_tags%22
sidebar_label: "add_tags|[\"metric\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/add_tags.rs
status: "prod-ready"
title: "Add Tags Transform"
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `add_tags` transform
accepts and outputs [`metric`][docs.data-model.metric] events allowing you to
add one or more metric tags.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/add_tags.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "add_tags" # required
  inputs = ["my-source-id"] # required

  # Tags
  tags.static_tag = "my value" # example
  tags.env_tag = "${ENV_VAR}" # example
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "add_tags" # required
  inputs = ["my-source-id"] # required

  # Tags
  tags.static_tag = "my value" # example
  tags.env_tag = "${ENV_VAR}" # example
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"tags"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### tags

A table of key/value pairs representing the tags to be added to the metric.



<Fields filters={false}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[{"static_tag":"my value"},{"env_tag":"${ENV_VAR}"}]}
  groups={[]}
  name={"`[tag-name]`"}
  path={"tags"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### `[tag-name]`

The name of the tag to add. Due to the nature of metric tags, the value must be
a string.




</Field>
</Fields>

</Field>
</Fields>

## How It Works

### Complex Processing

If you encounter limitations with the `add_tags`
transform then we recommend using a [runtime transform][urls.vector_programmable_transforms].
These transforms are designed for complex processing and give you the power of
full programming runtime.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.metric]: /docs/about/data-model/metric/
[urls.vector_programmable_transforms]: https://vector.dev/components/?functions%5B%5D=program
