---
last_modified_on: "2020-04-20"
component_title: "Lua"
description: "The Vector `lua` transform accepts and outputs `log` and `metric` events allowing you to transform events with a full embedded Lua engine."
event_types: ["log","metric"]
function_category: "program"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+lua%22
sidebar_label: "lua|[\"log\",\"metric\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/lua
status: "beta"
title: "Lua Transform"
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `lua` transform
accepts and outputs [`log`][docs.data-model.log] and
[`metric`][docs.data-model.metric] events allowing you to transform events with
a full embedded [Lua][urls.lua] engine.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/lua.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="simple"
  values={[{"label":"simple","value":"simple"},{"label":"inline","value":"inline"},{"label":"module","value":"module"}]}>
<TabItem value="simple">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "lua" # required
  inputs = ["my-source-id"] # required
  version = "2" # required

  # Hooks
  hooks.process = """
  function (event, emit)
    event.log.field = "value" -- set value of a field
    event.log.another_field = nil -- remove field
    event.log.first, event.log.second = nil, event.log.first -- rename field

    -- Very important! Emit the processed event.
    emit(event)
  end
  """
```

</TabItem>
<TabItem value="inline">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "lua" # required
  inputs = ["my-source-id"] # required
  version = "2" # required

  # Hooks
  hooks.init = """
  function (emit)
    count = 0 -- initialize state by setting a global variable
  end
  """
  hooks.process = """
  function (event, emit)
    count = count + 1 -- increment the counter and exit
  end
  """
  hooks.shutdown = """
  function (emit)
    emit {
      metric = {
        name = "event_counter",
        kind = "incremental",
        timestamp = os.date("!*t"),
        counter = {
          value = counter
        }
      }
    }
  end
  """

  # Timers
  timers.handler = """
  function (emit)
    emit {
      metric = {
        name = "event_counter",
        kind = "incremental",
        timestamp = os.date("!*t"),
        counter = {
          value = counter
        }
      }
    }
    counter = 0
  end
  """
  timers.interval_seconds = 1 # required, seconds
```

</TabItem>
<TabItem value="module">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "lua" # required
  inputs = ["my-source-id"] # required
  version = "2" # required
  search_dirs = ["/etc/vector/lua"] # optional, no default

  # Hooks
  hooks.init = "init" # optional, no default
  hooks.process = "process" # required
  hooks.shutdown = "shutdown" # optional, no default

  # Timers
  timers.handler = "timer_handler" # required
  timers.interval_seconds = 1 # required, seconds

  # Source Code
  source = """
  -- external file with hooks and timers defined
  require('custom_module')
  """
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={true}
  defaultValue={null}
  enumValues={{"2":"Lua transform API version 2"}}
  examples={["2"]}
  groups={["simple","inline","module"]}
  name={"version"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### version

Transform API version. Specifying this version ensures that Vector does not
break backward compatibility.




</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[["/etc/vector/lua"]]}
  groups={["module"]}
  name={"search_dirs"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

### search_dirs

A list of directories to search when loading a Lua file via the `require`
function. If not specified, the modules are looked up in the directories of
Vector's configs.

 See [Search Directories](#search-directories) for more info.


</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={["simple","inline","module"]}
  name={"hooks"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### hooks

Configures hooks handlers.



<Fields filters={false}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["function (emit)\n  count = 0 -- initialize state by setting a global variable\nend","init"]}
  groups={["inline","module"]}
  name={"init"}
  path={"hooks"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### init

A function which is called when the first event comes, before calling
`hooks.process`




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["function (event, emit)\n  event.log.field = \"value\" -- set value of a field\n  event.log.another_field = nil -- remove field\n  event.log.first, event.log.second = nil, event.log.first -- rename field\n\n  -- Very important! Emit the processed event.\n  emit(event)\nend","function (event, emit)\n  count = count + 1 -- increment the counter and exit\nend","process"]}
  groups={["simple","inline","module"]}
  name={"process"}
  path={"hooks"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### process

A function which is called for each incoming event. It can produce new events
using `emit` function.




</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["function (emit)\n  emit {\n    metric = {\n      name = \"event_counter\",\n      kind = \"incremental\",\n      timestamp = os.date(\"!*t\"),\n      counter = {\n        value = counter\n      }\n    }\n  }\nend","shutdown"]}
  groups={["inline","module"]}
  name={"shutdown"}
  path={"hooks"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### shutdown

A function which is called when Vector is stopped. It can produce new events
using `emit` function.




</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={["inline","module"]}
  name={"timers"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[table]"}
  unit={null}
  warnings={[]}
  >

### timers

Configures timers which are executed periodically at given interval.



<Fields filters={false}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["function (emit)\n  emit {\n    metric = {\n      name = \"event_counter\",\n      kind = \"incremental\",\n      timestamp = os.date(\"!*t\"),\n      counter = {\n        value = counter\n      }\n    }\n  }\n  counter = 0\nend","timer_handler"]}
  groups={["inline","module"]}
  name={"handler"}
  path={"timers"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### handler

Defines a handler function which is executed periodially at [`interval_seconds`](#interval_seconds).
It can produce new events using `emit` function.




</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[1,10,30]}
  groups={["inline","module"]}
  name={"interval_seconds"}
  path={"timers"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"integer"}
  unit={"seconds"}
  warnings={[]}
  >

#### interval_seconds

Defines the interval at which the timer handler would be executed.




</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["-- external file with hooks and timers defined\nrequire('custom_module')"]}
  groups={["module"]}
  name={"source"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### source

The source which is evaluated when the transform is created.




</Field>
</Fields>

## Examples

<Tabs
  block={false}
  defaultValue="add-rename--remove-log-fields"
  select={true}
  values={[{"label":"Add, rename, & remove log fields","value":"add-rename--remove-log-fields"},{"label":"Add, rename, & remove metric tags","value":"add-rename--remove-metric-tags"},{"label":"Drop event","value":"drop-event"}]}>

<TabItem value="add-rename--remove-log-fields">

The following examples demonstrates how to add, rename, and remove a [`log`][docs.data-model.log] event's fields:

```toml title="vector.toml"
# ...
hooks.process = """
function (event, emit)
  -- Add root level field
  event.log.field = "new value"

  -- Add nested field
  event.log.nested.field = "nested value"

  -- Rename field
  event.log.new_field = event.log.old_field
  event.log.old_field = nil

  -- Remove fields
  event.log.field = nil

  emit(event)
end
"""
```

</TabItem>

<TabItem value="add-rename--remove-metric-tags">

The following examples demonstrates how to add, rename, and remove a
[`metric`][docs.data-model.log] events's tags:

```toml title="vector.toml"
# ...
hooks.process = """
function (event, emit)
  -- Add tag
  event.metric.tags.tag = "new value"

  -- Rename tag
  event.metric.tags.new_tag = event.log.old_tag
  event.metric.tags.old_tag = nil

  -- Remove tag
  event.metric.tags.tag = nil

  emit(event)
end
"""
```

</TabItem>

<TabItem value="drop-event">

Drop an event entirely. Supply this as the `hooks.process` value:

```toml title="vector.toml"
# ...
hooks.process = """
function (event, emit)
  -- Drop event entirely by not calling the `emit` function
end
"""
```


</TabItem>
</Tabs>

## How It Works

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### Add Fields & Tags

To add `log` fields and `metric` tags just set the desired key to the
appropriate value:

```lua
-- Add root level field
event.log.field = "new value"

-- Add nested field
event.log.nested.field = "nested value"

-- Add tag
event.metric.tags.tag = "new value"
```

### Drop Events

To drop events, simply do not call the emitting function with it. For example:

```lua
function (event, emit)
  if not event["message"].match(str, "debug") then
    emit(event)
  end
end
```

### Remove Fields & Tags

You can remove `log` fields and `metric` tags by setting them to `nil`:

```lua
-- remove a log field
event.log.field = nil

-- remove a metric tag
event.metric.tags.tag = nil
```

### Representation of Events

Events are represented as [tables][urls.lua_table] in Lua. Vector uses
[externally tagged representation][urls.externally_tagged_representation] to
encode both log and metric events in a consistent fashion:

* [Log events][docs.about.data-model.log] are represented as values of a key
  named `log`.
* [Metric events][docs.about.data-model.metric] are represented as values of a
  key named `metric`.

<Tabs
  block={true}
  defaultValue="log"
  urlKey="event_type"
  values={[
    { label: 'Log', value: 'log', },
    { label: 'Metric', value: 'metric', },
  ]
}>
<TabItem value="log">

For instance, a typical [`log`][docs.data-model.log] event produced by the
[`stdin`][docs.sources.stdin] source could have been created programmatically
using the following code:

```lua
event = {
  log = {
    host = "localhost",
    message = "the message",
    timestamp = os.date("!*t")
  }
}
```

</TabItem>
<TabItem value="metric">

For instance, a typical [`metric`][docs.data-model.metric] event could have
been created programmatically in a similar way:

<Tabs
  defaultValue="counter"
  select={true}
  urlKey="metric_kind"
  values={[
    { label: 'Counter', value: 'counter', },
    { label: 'Gauge', value: 'gauge', },
    { label: 'Set', value: 'set', },
    { label: 'Distribution', value: 'distribution', },
    { label: 'Aggregated Histogram', value: 'aggregated_histogram', },
    { label: 'Aggregated Summary', value: 'aggregated_summary', },
  ]
}>
<TabItem value="counter">

```lua
event = {
  metric = {
    name = "login.count",
    timestamp = os.date("!*t"),
    kind = "absolute",
    tags = {
      host = "my.host.example"
    },
    counter = {
      value = 24.2
    }
  }
}
```

</TabItem>
<TabItem value="gauge">

```lua
event = {
  metric = {
    name = "memory_rss",
    timestamp = os.date("!*t"),
    kind = "absolute",
    tags = {
      host = "my.host.example"
    },
    gauge = {
      value = 512.0
    }
  }
}
```

</TabItem>
<TabItem value="set">

```lua
event = {
  metric = {
    name = "user_names",
    timestamp = os.date("!*t"),
    kind = "absolute",
    tags = {
      host = "my.host.example"
    },
    set = {
      values = {"value1", "value2"}
    }
  }
}
```

</TabItem>
<TabItem value="distribution">

```lua
event = {
  metric = {
    name = "response_time_ms",
    timestamp = os.date("!*t"),
    kind = "absolute",
    tags = {
      host = "my.host.example"
    },
    distribution = {
      values = {2.21, 5.46, 10.22},
      sample_rates = {5, 2, 5}
    }
  }
}
```

</TabItem>
<TabItem value="aggregated_histogram">

```lua
event = {
  metric = {
    name = "response_time_ms",
    timestamp = os.date("!*t"),
    kind = "absolute",
    tags = {
      host = "my.host.example"
    },
    aggregated_histogram = {
      buckets = {1.0, 2.0, 4.0, 8.0, 16.0, 32.0},
      counts = {20, 10, 45, 12, 18, 92},
      count = 197,
      sum = 975.2
    }
  }
}
```

</TabItem>
<TabItem value="aggregated_summary">

```lua
event = {
  metric = {
    name = "response_time_ms",
    timestamp = os.date("!*t"),
    kind = "absolute",
    tags = {
      host = "my.host.example"
    },
    aggregated_sumary = {
      quantiles = {0.1, 0.25, 0.5, 0.9, 0.99, 1.0},
      values = {2.0, 3.0, 5.0, 8.0, 9.0, 10.0},
      count = 197,
      sum = 975.2
    }
  }
}
```

</TabItem>
</Tabs>
</TabItem>
</Tabs>

#### Data Types

The correspondence between Vector's [data types][docs.about.data-model.log#types] and Lua data type is summarized
by the following table:

| Vector Type | Lua Type | Comment |
| :----------- | :-------- | :------- |
| [`String`][docs.about.data-model.log#strings] | [`string`][urls.lua_string] ||
| [`Integer`][docs.about.data-model.log#ints] | [`integer`][urls.lua_integer] ||
| [`Float`][docs.about.data-model.log#floats] | [`number`][urls.lua_number] ||
| [`Boolean`][docs.about.data-model.log#booleans] | [`boolean`][urls.lua_boolean] ||
| [`Timestamp`][docs.about.data-model.log#timestamps] | [`table`][urls.lua_table] | There is no dedicated timestamp type in Lua. Timestamps are represented as tables using the convention defined by [`os.date`][urls.lua_os_date] and [`os.time`][urls.lua_os_time]. The table representation of a timestamp contains the fields `year`, `month`, `day`, `hour`, `min`, `sec`, `nanosec`, `yday`, `wday`, and `isdst`. If such a table is passed from Lua to Vector, the fields  `yday`, `wday`, and `isdst` can be omitted. In addition to the `os.time` representation, Vector supports sub-second resolution with a `nanosec` field in the table. |
| [`Null`][docs.about.data-model.log#null-values] | empty string | In Lua setting the value of a table field to `nil` means deletion of this field. In addition, the length operator `#` does not work in the expected way with sequences containing nulls. Because of that `Null` values are encoded as empty strings. |
| [`Map`][docs.about.data-model.log#maps]| [`table`][urls.lua_table] | |
| [`Array`][docs.about.data-model.log#arrays] | [`sequence`][urls.lua_sequence] | Sequences are a special case of tables. Indexes start from 1, following the Lua convention. |

### Iterate Over Fields & Tags

To iterate over all fields of an `event` use the [`pairs`][urls.lua_pairs]
method.  For example:

```lua
function (event, emit)
  -- Remove all fields where the value is "-"
  for f, v in pairs(event) do
    if v == "-" then
      event[f] = nil
    end
  end

  emit(event)
end
```

### Defining timestamps

To parse a timestamp with an optional milliseconds field, like `2020-04-07 06:26:02.643` or `2020-04-07 06:26:02`:

```lua
timestamp_pattern = "(%d%d%d%d)[-](%d%d)[-](%d%d) (%d%d):(%d%d):(%d%d).?(%d*)"

function parse_timestamp(str)
  local year, month, day, hour, min, sec, millis = string.match(str, timestamp_pattern)
  local ms = 0
  if millis and millis ~= "" then
    ms = tonumber(millis)
  end
  return {
    year    = tonumber(year),
    month   = tonumber(month),
    day     = tonumber(day),
    hour    = tonumber(hour),
    min     = tonumber(min),
    sec     = tonumber(sec),
    nanosec = ms * 1000000
  }
end

parse_timestamp('2020-04-07 06:26:02.643')
parse_timestamp('2020-04-07 06:26:02')
```

### Search Directories

Vector provides a [`search_dirs`](#search_dirs) option that allows you to specify absolute
paths that will be searched when using the [Lua `require`
function][urls.lua_require]. If this option is not set, the directories of
the [configuration files][docs.setup.configuration] will be used instead.

### Lua Version

Vector uses the [`rlua` Rust crate][urls.rlua] which currently embeds Lua 5.3.

### Learning Lua

In order to write non-trivial transforms in Lua, one has to have basic
understanding of Lua. Because Lua is an easy to learn language, reading a few
first chapters of [the official book][urls.lua_pil] or consulting
[the manual][urls.lua_manual] would suffice.


[docs.about.data-model.log#arrays]: /docs/about/data-model/log/#arrays
[docs.about.data-model.log#booleans]: /docs/about/data-model/log/#booleans
[docs.about.data-model.log#floats]: /docs/about/data-model/log/#floats
[docs.about.data-model.log#ints]: /docs/about/data-model/log/#ints
[docs.about.data-model.log#maps]: /docs/about/data-model/log/#maps
[docs.about.data-model.log#null-values]: /docs/about/data-model/log/#null-values
[docs.about.data-model.log#strings]: /docs/about/data-model/log/#strings
[docs.about.data-model.log#timestamps]: /docs/about/data-model/log/#timestamps
[docs.about.data-model.log#types]: /docs/about/data-model/log/#types
[docs.about.data-model.log]: /docs/about/data-model/log/
[docs.about.data-model.metric]: /docs/about/data-model/metric/
[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.data-model.metric]: /docs/about/data-model/metric/
[docs.setup.configuration]: /docs/setup/configuration/
[docs.sources.stdin]: /docs/reference/sources/stdin/
[urls.externally_tagged_representation]: https://serde.rs/enum-representations.html#externally-tagged
[urls.lua]: https://www.lua.org/
[urls.lua_boolean]: https://www.lua.org/pil/2.2.html
[urls.lua_integer]: https://docs.rs/rlua/0.17.0/rlua/type.Integer.html
[urls.lua_manual]: https://www.lua.org/manual/5.3/manual.html
[urls.lua_number]: https://docs.rs/rlua/0.17.0/rlua/type.Number.html
[urls.lua_os_date]: https://www.lua.org/manual/5.3/manual.html#pdf-os.date
[urls.lua_os_time]: https://www.lua.org/manual/5.3/manual.html#pdf-os.time
[urls.lua_pairs]: https://www.lua.org/manual/5.3/manual.html#pdf-pairs
[urls.lua_pil]: https://www.lua.org/pil/
[urls.lua_require]: https://www.lua.org/manual/5.3/manual.html#pdf-require
[urls.lua_sequence]: https://www.lua.org/pil/11.1.html
[urls.lua_string]: https://www.lua.org/pil/2.4.html
[urls.lua_table]: https://www.lua.org/pil/2.5.html
[urls.rlua]: https://github.com/kyren/rlua
