---
last_modified_on: "2020-04-11"
component_title: "Regex Parser"
description: "The Vector `regex_parser` transform accepts and outputs `log` events allowing you to parse a log field's value with a Regular Expression."
event_types: ["log"]
function_category: "parse"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+regex_parser%22
sidebar_label: "regex_parser|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/regex_parser.rs
status: "prod-ready"
title: "Regex Parser Transform"
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `regex_parser` transform
accepts and outputs [`log`][docs.data-model.log] events allowing you to parse a
log field's value with a [Regular Expression][urls.regex].

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/regex_parser.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "regex_parser" # required
  inputs = ["my-source-id"] # required
  drop_field = true # optional, default
  field = "message" # optional, default
  regex = "^(?P<timestamp>[\\w\\-:\\+]+) (?P<level>\\w+) (?P<message>.*)$" # required

  # Types
  types.status = "int" # example
  types.duration = "float" # example
  types.success = "bool" # example
  types.timestamp = "timestamp|%F" # example
  types.timestamp = "timestamp|%a %b %e %T %Y" # example
  types.parent.child = "int" # example
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "regex_parser" # required
  inputs = ["my-source-id"] # required
  drop_field = true # optional, default
  field = "message" # optional, default
  overwrite_target = true # optional, default
  regex = "^(?P<timestamp>[\\w\\-:\\+]+) (?P<level>\\w+) (?P<message>.*)$" # required
  target_field = "root_field" # optional, no default

  # Types
  types.status = "int" # example
  types.duration = "float" # example
  types.success = "bool" # example
  types.timestamp = "timestamp|%F" # example
  types.timestamp = "timestamp|%a %b %e %T %Y" # example
  types.parent.child = "int" # example
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={true}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"drop_field"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### drop_field

If the specified [`field`](#field) should be dropped (removed) after parsing.




</Field>
<Field
  common={true}
  defaultValue={"message"}
  enumValues={null}
  examples={["message","parent.child"]}
  groups={[]}
  name={"field"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### field

The log field to parse.

 See [Failed Parsing](#failed-parsing) and [Field Notation Syntax](#field-notation-syntax) for more info.


</Field>
<Field
  common={false}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"overwrite_target"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### overwrite_target

If [`target_field`](#target_field) is set and the log contains a field of the same name as the
target, it will only be overwritten if this is set to `true`.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["^(?P<timestamp>[\\w\\-:\\+]+) (?P<level>\\w+) (?P<message>.*)$"]}
  groups={[]}
  name={"regex"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### regex

The Regular Expression to apply. Do not include the leading or trailing `/`.

 See [Failed Parsing](#failed-parsing) and [Regex Debugger](#regex-debugger) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["root_field","parent.child"]}
  groups={[]}
  name={"target_field"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### target_field

If this setting is present, the parsed fields will be inserted into the log as
a sub-object with this name. If a field with the same name already exists, the
parser will fail and produce an error.

 See [Field Notation Syntax](#field-notation-syntax) for more info.


</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"types"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### types

Key/value pairs representing mapped log field names and types. This is used to
coerce log fields into their proper types.

 See [Regex Syntax](#regex-syntax) for more info.

<Fields filters={false}>
<Field
  common={true}
  defaultValue={null}
  enumValues={{"bool":"Coerces `\"true\"`/`/\"false\"`, `\"1\"`/`\"0\"`, and `\"t\"`/`\"f\"` values into boolean.","float":"Coerce to a 64 bit float.","int":"Coerce to a 64 bit integer.","string":"Coerce to a string.","timestamp":"Coerces to a Vector timestamp. [`strptime` specificiers][urls.strptime_specifiers] must be used to parse the string."}}
  examples={[{"status":"int"},{"duration":"float"},{"success":"bool"},{"timestamp":"timestamp|%F"},{"timestamp":"timestamp|%a %b %e %T %Y"},{"parent":{"child":"int"}}]}
  groups={[]}
  name={"`[field-name]`"}
  path={"types"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### `[field-name]`

A definition of log field type conversions. They key is the log field name and
the value is the type. [`strptime` specifiers][urls.strptime_specifiers] are
supported for the `timestamp` type.




</Field>
</Fields>

</Field>
</Fields>

## Examples

Given the following log line:

```json title="log event"
{
  "message": "5.86.210.12 - zieme4647 5667 [19/06/2019:17:20:49 -0400] \"GET /embrace/supply-chains/dynamic/vertical\" 201 20574"
}
```

And the following configuration:

```toml title="vector.toml"
[transforms.<transform-id>]
  type = "regex_parser"
  field = "message"
  regex = '^(?P<host>[\w\.]+) - (?P<user>[\w]+) (?P<bytes_in>[\d]+) \[(?P<timestamp>.*)\] "(?P<method>[\w]+) (?P<path>.*)" (?P<status>[\d]+) (?P<bytes_out>[\d]+)$'

[transforms.<transform-id>.types]
  bytes_in = "int"
  timestamp = "timestamp|%d/%m/%Y:%H:%M:%S %z"
  status = "int"
  bytes_out = "int"
```

A [`log` event][docs.data-model.log] will be output with the following structure:

```javascript title="log event"
{
  // ... existing fields
  "bytes_in": 5667,
  "host": "5.86.210.12",
  "user_id": "zieme4647",
  "timestamp": <19/06/2019:17:20:49 -0400>,
  "message": "GET /embrace/supply-chains/dynamic/vertical",
  "status": 201,
  "bytes_out": 20574
}
```

Things to note about the output:

1. The `message` field was overwritten.
2. The `bytes_in`, `timestamp`, `status`, and `bytes_out` fields were coerced.

## How It Works

### Complex Processing

If you encounter limitations with the `regex_parser`
transform then we recommend using a [runtime transform][urls.vector_programmable_transforms].
These transforms are designed for complex processing and give you the power of
full programming runtime.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### Failed Parsing

If the [`field`](#field) value fails to parse against the provided [`regex`](#regex) then an error
will be [logged][docs.monitoring#logs] and the event will be kept or discarded
depending on the `drop_failed` value.

A failure includes any event that does not successfully parse against the
provided [`regex`](#regex). This includes bad values as well as events missing the
specified [`field`](#field).

### Field Notation Syntax

The [`field`](#field) and [`target_field`](#target_field) options
support [Vector's field notation syntax][docs.reference.field-path-notation],
enabling access to root-level, nested, and array field values. For example:

```toml title="vector.toml"
[transforms.my_regex_parser_transform_id]
  # ...
  field = "message"
  field = "parent.child"
  # ...
```

You can learn more about Vector's field notation in the
[field notation reference][docs.reference.field-path-notation].

### Performance

The `regex_parser` source has been involved in the following performance tests:

* [`regex_parsing_performance`][urls.regex_parsing_performance_test]

Learn more in the [Performance][pages.index#performance] sections.

### Regex Debugger

To test the validity of the[`regex`](#regex) option, we recommend the [Rust
Regex Tester][urls.regex_tester]. Note, you _must_ use
[named captures](#named-captures) in your regex to map the results to fields.

### Regex Syntax

Vector follows the [documented Rust Regex syntax][urls.rust_regex_syntax] since
Vector is written in Rust. This syntax follows a Perl-style regular expression
syntax, but lacks a few features like look around and backreferences.

#### Named Captures

You can name Regex captures with the `<name>` syntax. For example:

```text
^(?P<timestamp>\w*) (?P<level>\w*) (?P<message>.*)$
```

Will capture `timestamp`, `level`, and `message`. All values are extracted as
`string` values and must be coerced with the [`types`](#types) table.

More info can be found in the [Regex grouping and flags
documentation][urls.regex_grouping_and_flags].

#### Flags

Regex flags can be toggled with the `(?flags)` syntax. The available flags are:

| Flag | Descriuption |
| :--- | :----------- |
| `i`  | case-insensitive: letters match both upper and lower case |
| `m`  | multi-line mode: ^ and $ match begin/end of line |
| `s`  | allow . to match `\n` |
| `U`  | swap the meaning of `x*` and `x*?` |
| `u`  | Unicode support (enabled by default) |
| `x`  | ignore whitespace and allow line comments (starting with `#`)

For example, to enable the case-insensitive flag you can write:

```text
(?i)Hello world
```

More info can be found in the [Regex grouping and flags
documentation][urls.regex_grouping_and_flags].






### Value Coercion

Values can be coerced upon extraction via the [`types.*`](#types) options. This functions
exactly like the [`coercer` transform][docs.transforms.coercer] except that its
coupled within this transform for convenience.

#### Timestamps

You can coerce values into timestamps via the `timestamp` type:

```toml title="vector.toml"
# ...
types.first_timestamp = "timestamp" # best effort parsing
types.second_timestamp = "timestamp|%Y-%m-%dT%H:%M:%S%z" # ISO8601
# ...
```

As noted above, if you do not specify a specific `strftime` format, Vector
will make a best effort attempt to parse the timestamp against the following
common formats:

| Format               | Description                                  |
|:---------------------|:---------------------------------------------|
| **Without Timezone** |                                              |
| `%F %T`              | YYYY-MM-DD HH:MM:SS                          |
| `%v %T`              | DD-Mmm-YYYY HH:MM:SS                         |
| `FT%T`               | ISO 8601 / RFC 3339 without TZ               |
| `m/%d/%Y:%T`         | US common date format                        |
| `a, %d %b %Y %T`     | RFC 822/2822 without TZ                      |
| `a %d %b %T %Y`      | `date` command output without TZ             |
| `A %d %B %T %Y`      | `date` command output without TZ, long names |
| `a %b %e %T %Y`      | ctime format                                 |
| **With Timezone**    |                                              |
| `%+`                 | ISO 8601 / RFC 3339                          |
| `%a %d %b %T %Z %Y`  | `date` command output                        |
| `%a %d %b %T %z %Y`  | `date` command output, numeric TZ            |
| `%a %d %b %T %#z %Y` | `date` command output, numeric TZ            |
| **UTC Formats**      |                                              |
| `%s`                 | UNIX timestamp                               |
| `%FT%TZ`             | ISO 8601 / RFC 3339 UTC                      |


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.monitoring#logs]: /docs/administration/monitoring/#logs
[docs.reference.field-path-notation]: /docs/reference/field-path-notation/
[docs.transforms.coercer]: /docs/reference/transforms/coercer/
[pages.index#performance]: /#performance
[urls.regex]: https://en.wikipedia.org/wiki/Regular_expression
[urls.regex_grouping_and_flags]: https://docs.rs/regex/1.3.6/regex/#grouping-and-flags
[urls.regex_parsing_performance_test]: https://github.com/timberio/vector-test-harness/tree/master/cases/regex_parsing_performance
[urls.regex_tester]: https://rustexp.lpil.uk/
[urls.rust_regex_syntax]: https://docs.rs/regex/1.3.6/regex/#syntax
[urls.strptime_specifiers]: https://docs.rs/chrono/0.4.11/chrono/format/strftime/index.html#specifiers
[urls.vector_programmable_transforms]: https://vector.dev/components/?functions%5B%5D=program
