---
last_modified_on: "2020-04-11"
component_title: "Remove Fields"
description: "The Vector `remove_fields` transform accepts and outputs `log` events allowing you to remove one or more log fields."
event_types: ["log"]
function_category: "shape"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+remove_fields%22
sidebar_label: "remove_fields|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/remove_fields.rs
status: "prod-ready"
title: "Remove Fields Transform"
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `remove_fields` transform
accepts and outputs [`log`][docs.data-model.log] events allowing you to remove
one or more log fields.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/remove_fields.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[transforms.my_transform_id]
  type = "remove_fields" # required
  inputs = ["my-source-id"] # required
  fields = ["field1", "field2", "parent.child"] # required
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[transforms.my_transform_id]
  type = "remove_fields" # required
  inputs = ["my-source-id"] # required
  drop_empty = false # optional, default
  fields = ["field1", "field2", "parent.child"] # required
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={false}
  defaultValue={false}
  enumValues={null}
  examples={[false,true]}
  groups={[]}
  name={"drop_empty"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### drop_empty

If set to `true`, after removing fields, remove any parent objects that are now
empty.




</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[["field1","field2","parent.child"]]}
  groups={[]}
  name={"fields"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

### fields

The log field names to drop.

 See [Field Notation Syntax](#field-notation-syntax) for more info.


</Field>
</Fields>

## How It Works

### Complex Processing

If you encounter limitations with the `remove_fields`
transform then we recommend using a [runtime transform][urls.vector_programmable_transforms].
These transforms are designed for complex processing and give you the power of
full programming runtime.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### Field Notation Syntax

The [`fields`](#fields) options
support [Vector's field notation syntax][docs.reference.field-path-notation],
enabling access to root-level, nested, and array field values. For example:

```toml title="vector.toml"
[transforms.my_remove_fields_transform_id]
  # ...
  fields = ["field1", "field2", "parent.child"]
  # ...
```

You can learn more about Vector's field notation in the
[field notation reference][docs.reference.field-path-notation].

### Nested Field Removal

Nested fields are removed in a _deep_ fashion. They will not remove any
ancestor object. For example, given the following `log` event:

```javascript
{
  "parent": {
    "child1": "value1",
    "child2": "value2"
  }
}
```

And the following configuration:

```toml
[transforms.remove_nested_field]
  type = "remove_fields"
  fields = ["parent.child2"]
```

Will result in the following log event:

```javascript
{
  "parent": {
    "child1": "value1",
  }
}
```

Notice that `parent.child1` field was preserved.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.reference.field-path-notation]: /docs/reference/field-path-notation/
[urls.vector_programmable_transforms]: https://vector.dev/components/?functions%5B%5D=program
