---
last_modified_on: "2020-04-19"
$schema: "/.meta/.schemas/guides.json"
title: "Send logs from STDIN to Apache Pulsar"
description: "A simple guide to send logs from STDIN to Apache Pulsar in just a few minutes."
author_github: https://github.com/binarylogic
cover_label: "STDIN to Apache Pulsar Integration"
tags: ["type: tutorial","domain: sources","domain: sinks","source: stdin","sink: pulsar"]
hide_pagination: true
---

import ConfigExample from '@site/src/components/ConfigExample';
import InstallationCommand from '@site/src/components/InstallationCommand';
import Jump from '@site/src/components/Jump';
import SidecarDiagram from '@site/src/components/SidecarDiagram';
import Steps from '@site/src/components/Steps';

Logs are an _essential_ part of observing any
service; without them you are flying blind. But collecting and analyzing them
can be a real challenge -- especially at scale. Not only do you need to solve
the basic task of collecting your logs, but you must do it
in a reliable, performant, and robust manner. Nothing is more frustrating than
having your logs pipeline fall on it's face during an
outage, or even worse, disrupt more important services!

Fear not! In this guide we'll show you how to send send logs from [STDIN][urls.stdin] to [Apache Pulsar][urls.pulsar]
and build a logs pipeline that will be the backbone of
your observability strategy.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/guides/integrate/sources/stdin/pulsar.md.erb
-->

## Background

### What is Apache Pulsar?

[Pulsar][urls.pulsar] is a multi-tenant, high-performance solution for server-to-server messaging. Pulsar was originally developed by Yahoo, it is under the stewardship of the Apache Software Foundation. It is an excellent tool for streaming logs and metrics data.

## Strategy

### How This Guide Works

We'll be using [Vector][urls.vector_website] to accomplish this task. Vector
is a [popular][urls.vector_stars] [open-source][urls.vector_repo] utility for
building observability pipelines. It's written in [Rust][urls.rust], making it
lightweight, [ultra-fast][urls.vector_performance] and highly reliable. And
we'll be deploying Vector as a
[sidecar][docs.strategies#sidecar].

The [sidecar deployment strategy][docs.strategies#sidecar] is designed to
collect data from a _single_ service. Vector has a tight 1 to 1 coupling with
each service. Typically data is collected by tailing local files via Vector's
[`file` source][docs.sources.file], but can be collected through any of Vector's
[sources][docs.sources]. The following diagram demonstrates how it works.

<SidecarDiagram
  platformName={null}
  sourceName={"stdin"}
  sinkName={"pulsar"} />

### What We'll Accomplish

To be clear, here's everything we'll accomplish in this short guide:

<ul className="list--icons list--icons--checks list--indent">
  <li>
    Accept new line delimited log data through STDIN.
    <ul>
      <li>Automatically enrich logs with host-level context.</li>
    </ul>
  </li>
  <li>
    Send logs to Apache Pulsar.
    <ul>
      <li>Stream data in a real-time fashion.</li>
      <li>Automatically retry failed requests, with backoff.</li>
    </ul>
  </li>
  <li className="list--icons--arrow text--pink text--bold">All in just a few minutes!</li>
</ul>

## Tutorial

<Steps headingDepth={3}>
<ol>
<li>

### Install Vector

<InstallationCommand />

</li>
<li>

### Configure Vector

<ConfigExample
  format="toml"
  path={"vector.toml"}
  sourceName={"stdin"}
  sinkName={"pulsar"} />

</li>
<li>

### Start Vector

```bash
vector --config vector.toml
```

That's it! Simple and to the point. Hit `ctrl+c` to exit.

</li>
</ol>
</Steps>

## Next Steps

Vector is _powerful_ utility and we're just scratching the surface in this
guide. Here are a few pages we recommend that demonstrate the power and
flexibility of Vector:

<Jump to="https://github.com/timberio/vector" leftIcon="github" target="_blank">
  <div className="title">Vector Github repo <span className="badge badge--primary"><i className="feather icon-star"></i> 4k</span></div>
  <div className="sub-title">Vector is free and open-source!</div>
</Jump>

<Jump to="/guides/getting-started/" leftIcon="book">
  <div className="title">Vector getting started series</div>
  <div className="sub-title">Go from zero to production in under 10 minutes!</div>
</Jump>

<Jump to="/docs/about/what-is-vector/" leftIcon="book">
  <div className="title">Vector documentation</div>
  <div className="sub-title">Thoughtful, detailed docs that respect your time.</div>
</Jump>


[docs.sources.file]: /docs/reference/sources/file/
[docs.sources]: /docs/reference/sources/
[docs.strategies#sidecar]: /docs/setup/deployment/strategies/#sidecar
[urls.pulsar]: https://pulsar.apache.org/
[urls.rust]: https://www.rust-lang.org/
[urls.stdin]: https://en.wikipedia.org/wiki/Standard_streams#Standard_input_(stdin)
[urls.vector_performance]: https://vector.dev/#performance
[urls.vector_repo]: https://github.com/timberio/vector
[urls.vector_stars]: https://github.com/timberio/vector/stargazers
[urls.vector_website]: https://vector.dev
